'use client';

import { useState, useEffect } from 'react';
import { motion } from 'framer-motion';
import { FiPlus, FiEdit2, FiTrash2 } from 'react-icons/fi';
import { getSubjects, deleteSubject } from '@/utils/firebase_utils';
import type { Subject } from '@/types/education';
import { useRouter } from 'next/navigation';

export default function SubjectsPage() {
  const [subjects, setSubjects] = useState<Subject[]>([]);
  const [loading, setLoading] = useState(true);
  const router = useRouter();

  useEffect(() => {
    loadSubjects();
  }, []);

  const loadSubjects = async () => {
    try {
      setLoading(true);
      const response = await getSubjects({ isActive: true });
      setSubjects(response.items);
    } catch (error) {
      console.error('Error loading subjects:', error);
    } finally {
      setLoading(false);
    }
  };

  const handleDelete = async (id: string) => {
    if (!window.confirm('Are you sure you want to delete this subject?')) return;
    try {
      await deleteSubject(id);
      setSubjects(prev => prev.filter(subject => subject.id !== id));
    } catch (error) {
      console.error('Error deleting subject:', error);
    }
  };

  if (loading) {
    return (
      <div className="space-y-4">
        {[1, 2, 3].map((i) => (
          <div key={i} className="bg-[#1a1a1a] p-6 rounded-lg animate-pulse">
            <div className="h-6 w-48 bg-[#2a2a2a] rounded mb-2"></div>
            <div className="h-4 w-64 bg-[#2a2a2a] rounded"></div>
          </div>
        ))}
      </div>
    );
  }

  return (
    <div className="space-y-6">
      {/* Header */}
      <div className="flex justify-between items-center">
        <div>
          <h1 className="text-2xl font-bold text-white">Subjects</h1>
          <p className="text-gray-400">Manage educational subjects</p>
        </div>
        <motion.button
          whileHover={{ scale: 1.02 }}
          whileTap={{ scale: 0.98 }}
          onClick={() => router.push('/admin/content/subjects/new')}
          className="px-4 py-2 bg-[#FF6B2B] text-white rounded-lg hover:bg-[#FF6B2B]/90 
            flex items-center space-x-2"
        >
          <FiPlus className="w-5 h-5" />
          <span>Add Subject</span>
        </motion.button>
      </div>

      {/* Subjects Grid */}
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
        {subjects.map((subject, index) => (
          <motion.div
            key={subject.id}
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ delay: index * 0.1 }}
            className="bg-[#1a1a1a] rounded-lg p-6 group hover:bg-[#2a2a2a] transition-colors"
          >
            <div className="flex items-start justify-between">
              <div className="flex-1">
                <h3 className="text-white font-semibold text-lg">{subject.name}</h3>
                <p className="text-gray-400 text-sm mt-1">{subject.description}</p>
                <div className="flex items-center space-x-2 mt-2">
                  <span className="px-2 py-1 bg-[#FF6B2B]/10 text-[#FF6B2B] text-xs rounded-full">
                    {subject.category}
                  </span>
                  <span className="px-2 py-1 bg-[#2a2a2a] text-gray-300 text-xs rounded-full">
                    Topics
                  </span>
                </div>
              </div>
              <div className="flex space-x-2 opacity-0 group-hover:opacity-100 transition-opacity">
                <motion.button
                  whileHover={{ scale: 1.1 }}
                  whileTap={{ scale: 0.9 }}
                  onClick={() => router.push(`/admin/content/subjects/${subject.id}/edit`)}
                  className="p-2 bg-blue-500/10 text-blue-500 rounded-lg hover:bg-blue-500/20"
                >
                  <FiEdit2 className="w-4 h-4" />
                </motion.button>
                <motion.button
                  whileHover={{ scale: 1.1 }}
                  whileTap={{ scale: 0.9 }}
                  onClick={() => handleDelete(subject.id)}
                  className="p-2 bg-red-500/10 text-red-500 rounded-lg hover:bg-red-500/20"
                >
                  <FiTrash2 className="w-4 h-4" />
                </motion.button>
              </div>
            </div>
          </motion.div>
        ))}
      </div>

      {subjects.length === 0 && (
        <div className="text-center py-12 bg-[#1a1a1a] rounded-lg">
          <p className="text-gray-400">No subjects found. Add your first subject to get started.</p>
        </div>
      )}
    </div>
  );
} 